@@ -445,6 +445,26 @@ struct button buttons[NKEYS] = {
     NULL,
     0
 },
+{
+    KEY_SET_BASE,
+    NULL,
+    0
+},
+{
+    KEY_SET_NUMBERTYPE,
+    NULL,
+    0
+},
+{
+    KEY_UNDO,
+    NULL,
+    0
+},
+{
+    KEY_REDO,
+    NULL,
+    0
+},
 {
     KEY_CONSTANT,
     NULL,
@@ -602,7 +622,6 @@ init_state(void)
     mpset(&acc, &size, &size);
 
     v->error       = 0;            /* No calculator error initially. */    
-    v->current    = KEY_CALCULATE;
 
     init_constant(0, "0.621");                 /* kms/hr <=> miles/hr. */
     init_constant(1, "1.4142135623");          /* square root of 2 */
@@ -656,8 +675,6 @@ main(int argc, char **argv)
     read_resources();          /* Read resources from merged database. */
     ui_load();
 
-    do_clear();                /* Initialise and clear display. */
-
     ui_start();                /* Display the calculator. */
     
     return(0);
